Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxManageInfo.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxManageInfo.cpp	(revision 31216)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxManageInfo.cpp	(revision 31217)
@@ -1945,5 +1945,5 @@
             if (details == VMINFO_FULL)
             {
-                rc = guest->COMGETTER(AdditionsVersion)(guestString.asOutParam());
+                rc = guest->COMGETTER(AdditionsVBoxVersion)(guestString.asOutParam());
                 if (   SUCCEEDED(rc)
                     && !guestString.isEmpty())
Index: /trunk/src/VBox/Frontends/VirtualBox/src/VBoxVMInformationDlg.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/VBoxVMInformationDlg.cpp	(revision 31216)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/VBoxVMInformationDlg.cpp	(revision 31217)
@@ -472,5 +472,5 @@
         if (!addVersion.isEmpty() && !addRevision.isEmpty())
         {
-            QString addInfo = console.GetGuest().GetAdditionsVersion();
+            QString addInfo = console.GetGuest().GetAdditionsVBoxVersion();
             addVersionStr = (addInfo.isEmpty() ? "(" : "")
                           + addVersion
Index: /trunk/src/VBox/Main/GuestImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/GuestImpl.cpp	(revision 31216)
+++ /trunk/src/VBox/Main/GuestImpl.cpp	(revision 31217)
@@ -176,7 +176,7 @@
 }
 
-STDMETHODIMP Guest::COMGETTER(AdditionsVersion) (BSTR *aAdditionsVersion)
-{
-    CheckComArgOutPointerValid(aAdditionsVersion);
+STDMETHODIMP Guest::COMGETTER(AdditionsInterfaceVersion) (BSTR *aVersion)
+{
+    CheckComArgOutPointerValid(aVersion);
 
     AutoCaller autoCaller(this);
@@ -185,5 +185,19 @@
     AutoReadLock alock(this COMMA_LOCKVAL_SRC_POS);
 
-    mData.mAdditionsVersion.cloneTo(aAdditionsVersion);
+    mData.mInterfaceVersion.cloneTo(aVersion);
+
+    return S_OK;
+}
+
+STDMETHODIMP Guest::COMGETTER(AdditionsVBoxVersion) (BSTR *aVersion)
+{
+    CheckComArgOutPointerValid(aVersion);
+
+    AutoCaller autoCaller(this);
+    if (FAILED(autoCaller.rc())) return autoCaller.rc();
+
+    AutoReadLock alock(this COMMA_LOCKVAL_SRC_POS);
+
+    mData.mAdditionsVersion.cloneTo(aVersion);
 
     return S_OK;
@@ -1443,8 +1457,8 @@
  * API version and OS type.
  *
- * @param aVersion
+ * @param aInterfaceVersion
  * @param aOsType
  */
-void Guest::setAdditionsInfo(Bstr aVersion, VBOXOSTYPE aOsType)
+void Guest::setAdditionsInfo(Bstr aInterfaceVersion, VBOXOSTYPE aOsType)
 {
     AutoCaller autoCaller(this);
@@ -1457,5 +1471,5 @@
      * Note that this is *not* the actual Guest Additions version and may differ!
      */
-    mData.mAdditionsVersion = aVersion;
+    mData.mInterfaceVersion = aInterfaceVersion;
     /*
      * Older Additions rely on the Additions API version whether they
@@ -1463,5 +1477,5 @@
      * this immediately.
      */
-    mData.mAdditionsActive = !aVersion.isEmpty();
+    mData.mAdditionsActive = !aInterfaceVersion.isEmpty();
     /*
      * Older Additions didn't have this finer grained capability bit,
@@ -1487,5 +1501,5 @@
  * @param ulFlags
  */
-void Guest::setAdditionsStatus (VBoxGuestStatusFacility Facility, VBoxGuestStatusCurrent Status, ULONG ulFlags)
+void Guest::setAdditionsStatus(VBoxGuestStatusFacility Facility, VBoxGuestStatusCurrent Status, ULONG ulFlags)
 {
     AutoCaller autoCaller(this);
@@ -1507,5 +1521,5 @@
  * @param ulActive
  */
-void Guest::setSupportedFeatures (ULONG64 ulCaps, ULONG64 ulActive)
+void Guest::setSupportedFeatures(ULONG64 ulCaps, ULONG64 ulActive)
 {
     AutoCaller autoCaller(this);
Index: /trunk/src/VBox/Main/idl/VirtualBox.xidl
===================================================================
--- /trunk/src/VBox/Main/idl/VirtualBox.xidl	(revision 31216)
+++ /trunk/src/VBox/Main/idl/VirtualBox.xidl	(revision 31217)
@@ -7732,5 +7732,5 @@
   <interface
      name="IGuest" extends="$unknown"
-     uuid="d915dff1-ed38-495a-91f1-ab6c53932468"
+     uuid="a3f4b219-ae2a-464c-b488-36cd8ac06b79"
      wsmap="managed"
      >
@@ -7767,11 +7767,20 @@
     </attribute>
 
-    <attribute name="additionsVersion" type="wstring" readonly="yes">
-      <desc>
-        Version of the Guest Additions (3 decimal numbers separated
-        by dots) or empty when the Additions are not installed. The
-        Additions may also report a version but yet not be active as
-        the version might be refused by VirtualBox (incompatible) or
-        other failures occurred.
+    <attribute name="additionsVBoxVersion" type="wstring" readonly="yes">
+      <desc>
+        Version of the installed Guest Additions package (3 decimal numbers
+        separated by dots) or empty when the Additions are not installed. The
+        Additions may also report a version but yet not be active as the version
+        might be refused by VirtualBox (incompatible) or other failures
+        occurred.
+      </desc>
+    </attribute>
+
+    <attribute name="additionsInterfaceVersion" type="wstring" readonly="yes">
+      <desc>
+        Version of the Guest Additions interface (2 decimal numbers separated by
+        a dot) or empty when the Additions are not installed. The Additions may
+        also report a version but yet not be active as the version might be
+        refused by VirtualBox (incompatible) or other failures occurred.
       </desc>
     </attribute>
Index: /trunk/src/VBox/Main/include/GuestImpl.h
===================================================================
--- /trunk/src/VBox/Main/include/GuestImpl.h	(revision 31216)
+++ /trunk/src/VBox/Main/include/GuestImpl.h	(revision 31217)
@@ -80,9 +80,6 @@
 #endif
     STDMETHOD(COMGETTER(AdditionsActive)) (BOOL *aAdditionsActive);
-#if 0
-    /** @todo Will replace AdditionsVersion to be more clear. */
-    STDMETHOD(COMGETTER(AdditionsAPIVersion)) (BSTR *aAdditionsVersion);
-#endif
-    STDMETHOD(COMGETTER(AdditionsVersion)) (BSTR *aAdditionsVersion);
+    STDMETHOD(COMGETTER(AdditionsInterfaceVersion)) (BSTR *aVersion);
+    STDMETHOD(COMGETTER(AdditionsVBoxVersion)) (BSTR *aVersion);
     /** @todo Remove */
     STDMETHOD(COMGETTER(SupportsSeamless)) (BOOL *aSupportsSeamless);
@@ -175,4 +172,5 @@
         BOOL  mAdditionsActive;
         Bstr  mAdditionsVersion;
+        Bstr  mInterfaceVersion;
         BOOL  mSupportsSeamless;
         BOOL  mSupportsGraphics;

Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 31216)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 31217)
@@ -828,7 +828,7 @@
     if (!fIsAdditionsActive)
         return;
     /* Check the Guest Additions version and warn the user about possible compatibility issues in case if the installed version is outdated. */
     CGuest guest = session().GetConsole().GetGuest();
-    QString strVersion = guest.GetAdditionsVersion();
+    QString strVersion = guest.GetAdditionsInterfaceVersion();
     uint uVersion = strVersion.toUInt();
     /** @todo r=bird: This isn't want we want! We want the VirtualBox version of the additions, all three numbers. See @bugref{4084}.*/
@@ -828,7 +828,7 @@
     if (!fIsAdditionsActive)
         return;
-    /* Check the Guest Additions version and warn the user about possible compatibility issues in case if the installed version is outdated. */
+    /* Check the Guest Additions interface version and warn the user about possible compatibility issues in case if the installed version is outdated. */
     CGuest guest = session().GetConsole().GetGuest();